# Raspberry PI

Restituisce una lista di tutti i service
sudo systemctl --type=service

pipkin per installare i moduli python su Raspberry Pico W

Utilizzare questo parametro '--break-system-packages' per bypassare il pip install del Raspberry PI Model B
pip3 install Strawberry-PI --break-system-package
